import {Component, Input} from '@angular/core';
import {IDataSource, ISimpleFilter} from '@poweredsoft/data';
import {PopoverDirective, PopoverModule} from 'ngx-bootstrap/popover';
import {FormsModule} from "@angular/forms";
import {TooltipModule} from "ngx-bootstrap/tooltip";
import {CommonModule} from "@angular/common";

@Component({
  selector: 'bsx-ds-text-filter',
  templateUrl: './data-source-text-filter.component.html',
  styleUrls: ['./data-source-text-filter.component.scss'],
  standalone: true,
  imports: [
    CommonModule,
    FormsModule,
    TooltipModule,
    PopoverModule,
  ]
})
export class DataSourceTextFilterComponent {
  @Input() dataSource : IDataSource<any>;
  @Input() path: string;

  filterType: string = 'Contains';
  filterValue: string = null;
  isFiltering: boolean;
  filterIsOpened: boolean = false;

  filterTypes = [
    {key:'Contains', value: 'Contains'},
    {key:'Equals', value: 'Equal'},
    {key:'Starts With', value: 'startsWith'},
    {key:'Ends With', value: 'endsWith'}
  ];

  clearFilter() {
    this.filterValue = '';
    this.isFiltering = false;
    const existingFilter = this.dataSource.filters.find(t => (t as ISimpleFilter).path == this.path) as ISimpleFilter;
    if (existingFilter) {
      this.dataSource.query({
        page: 1,
        filters: this.dataSource.filters.filter(t => t != existingFilter)
      })
    }
  }

  applyFilter(pop: PopoverDirective = null){
    this.isFiltering = true;
    const filters = this.dataSource.filters;
    const existingFilter = filters.find(t => (t as ISimpleFilter).path == this.path) as ISimpleFilter;
    if (existingFilter) {
      existingFilter.type = this.filterType;
      existingFilter.value = this.filterValue;
    } else {
      filters.push(<ISimpleFilter>{
        and: true,
        type: this.filterType,
        path: this.path,
        value: this.filterValue
      })
    }

    this.dataSource.query({
      filters: filters,
      page: 1
    })

    if (pop)
      pop.hide();
  }

  showTooltip(){
    return "Filter by "+ this.path;
  }
}
